@@ -14,7 +14,7 @@
 
 #pragma once
 
-#if defined(_WIN32) // Settings specific to Windows
+#if defined(_WIN32)
 
 #if _MSC_VER >= 1900
 #define CPPREST_NOEXCEPT noexcept
@@ -22,15 +22,13 @@
 #else
 #define CPPREST_NOEXCEPT
 #define CPPREST_CONSTEXPR const
-#endif
+#endif // _MSC_VER >= 1900
 
 #define CASABLANCA_UNREFERENCED_PARAMETER(x) (x)
 
 #include <sal.h>
 
-#else // End settings specific to Windows
-
-// Settings common to all but Windows
+#else // ^^^ _WIN32 ^^^ // vvv !_WIN32 vvv
 
 #define __declspec(x) __attribute__ ((x))
 #define dllimport
@@ -49,9 +47,10 @@
 #if not defined __cdecl
 #if defined cdecl
 #define __cdecl __attribute__ ((cdecl))
-#else
+#else // ^^^ defined cdecl ^^^ // vvv !defined cdecl vvv
 #define __cdecl
-#endif
+#endif // defined cdecl
+#endif // not defined __cdecl
 
 #if defined(__ANDROID__)
 // This is needed to disable the use of __thread inside the boost library.
@@ -61,30 +60,27 @@
 // the .so from loading.
 #if not defined BOOST_ASIO_DISABLE_THREAD_KEYWORD_EXTENSION
 #define BOOST_ASIO_DISABLE_THREAD_KEYWORD_EXTENSION
-#endif
-#endif
+#endif // not defined BOOST_ASIO_DISABLE_THREAD_KEYWORD_EXTENSION
+#endif // defined(__ANDROID__)
 
 #ifdef __clang__
 #include <cstdio>
-#endif
-
-#endif // defined(__APPLE__)
-
-#endif
+#endif // __clang__
+#endif // _WIN32
 
 
 #ifdef _NO_ASYNCRTIMP
 #define _ASYNCRTIMP
-#else
+#else // ^^^ _NO_ASYNCRTIMP ^^^ // vvv !_NO_ASYNCRTIMP vvv
 #ifdef _ASYNCRT_EXPORT
 #define _ASYNCRTIMP __declspec(dllexport)
-#else
+#else // ^^^ _ASYNCRT_EXPORT ^^^ // vvv !_ASYNCRT_EXPORT vvv
 #define _ASYNCRTIMP __declspec(dllimport)
-#endif
-#endif
+#endif // _ASYNCRT_EXPORT
+#endif // _NO_ASYNCRTIMP
 
 #ifdef CASABLANCA_DEPRECATION_NO_WARNINGS
 #define CASABLANCA_DEPRECATED(x)
 #else
 #define CASABLANCA_DEPRECATED(x) __declspec(deprecated(x))
-#endif
+#endif // CASABLANCA_DEPRECATION_NO_WARNINGS
