@@ -12,8 +12,8 @@
 ****/
 #pragma once
 
-#ifndef _CASA_FILE_STREAMS_H
-#define _CASA_FILE_STREAMS_H
+#ifndef CASA_FILE_STREAMS_H
+#define CASA_FILE_STREAMS_H
 
 #include "cpprest/details/fileio.h"
 #include "cpprest/astreambuf.h"
@@ -311,7 +311,7 @@ namespace details {
         /// <summary>
         /// Submits a block already allocated by the stream buffer.
         /// </summary>
-        /// <param name="ptr">Count of characters to be commited.</param>
+        /// <param name="ptr">Count of characters to be committed.</param>
         void _commit(size_t)
         {
         }
@@ -320,7 +320,7 @@ namespace details {
         /// Gets a pointer to the next already allocated contiguous block of data.
         /// </summary>
         /// <param name="ptr">A reference to a pointer variable that will hold the address of the block on success.</param>
-        /// <param name="count">The number of contiguous characters available at the address in 'ptr.'</param>
+        /// <param name="count">The number of contiguous characters available at the address in 'ptr'.</param>
         /// <returns><c>true</c> if the operation succeeded, <c>false</c> otherwise.</returns>
         /// <remarks>
         /// A return of false does not necessarily indicate that a subsequent read operation would fail, only that
@@ -1033,7 +1033,7 @@ namespace details {
         }
 
         /// <summary>
-        /// Open a new ouput stream representing the given file.
+        /// Open a new output stream representing the given file.
         /// If the file does not exist, it will be create unless the folder or directory
         /// where it is to be found also does not exist.
         /// </summary>
@@ -1079,7 +1079,7 @@ namespace details {
         }
 
         /// <summary>
-        /// Open a new ouput stream representing the given file.
+        /// Open a new output stream representing the given file.
         /// If the file does not exist, it will be create unless the folder or directory
         /// where it is to be found also does not exist.
         /// </summary>
