@@ -10,8 +10,8 @@
 ****/
 #pragma once
 
-#ifndef _CASA_WS_CLIENT_H
-#define _CASA_WS_CLIENT_H
+#ifndef CASA_WS_CLIENT_H
+#define CASA_WS_CLIENT_H
 
 #include "cpprest/details/basic_types.h"
 
@@ -142,7 +142,7 @@ public:
     }
 
     /// <summary>
-    /// Gets the server host name to usefor TLS Server Name Indication (SNI).
+    /// Gets the server host name to use for TLS Server Name Indication (SNI).
     /// </summary>
     /// <returns>Host name as a string.</returns>
     const utf8string & server_name() const
